
// GraphColors.java
// Krzysztof Kuchcinski, Jacop Slides, 2013 (?)
// Slightly modified by Andrew Davison, ad@fivedots.coe.psu.ac.th, Dec. 2022

/* Graph coloring of:

    V1 --- V3
     | \    |
     |  \   |
     |   \  |
    V0 --- V2

  Usage:
     > compile GraphColors.java
     > run GraphColors
       v0 = 1;  v1 = 2;  v2 = 3;  v3 = 1;
*/


import org.jacop.core.*;
import org.jacop.constraints.*;
import org.jacop.search.*;

// import java.util.*;


public class GraphColors
{
  private static int NUM_COLORS = 3;

  public static void main (String[] args)
  {
    Store store = new Store();

    // create constraint variables
    IntVar[] vs = new IntVar[4];
    for (int i=0; i < vs.length; i++)
      vs[i] = new IntVar(store, "v"+i, 1, NUM_COLORS);
                       // range of 'colors' is 1..NUM_COLORS

    // constraints: adjacent nodes cannot have same color 
    store.impose( new XneqY(vs[0], vs[1]) );
    store.impose( new XneqY(vs[0], vs[2]) );
    store.impose( new XneqY(vs[1], vs[2]) );
    store.impose( new XneqY(vs[1], vs[3]) );
    store.impose( new XneqY(vs[2], vs[3]) );

    SelectChoicePoint<IntVar> select =
      new SimpleSelect<>(vs, null, new IndomainMin<>());
         //  tries assigning the minimal value in the domain first

    Search<IntVar> search = new DepthFirstSearch<>();
    search.setPrintInfo(false);
    search.labeling(store, select);
    JacopUtils.printSolns(search);
  }  // end of main()

}  // end of GraphColors class